###############################################################################
#
# Copyright (C) 2013 Wind River Systems, Inc.
#
# This code is licensed under the GPLv2.
#
###############################################################################


import sys
import subprocess
import os

###############################################################################
# Class definition
#
# This class implements a simple command line executor. It will try to execute
# a given command line, in case of error writing to the STDERR an error message
###############################################################################
class OVP_OTT_EXECUTOR:

    # This method implements the command execution task. The pCommand
    # parameter represents the command that shall be executed, or that shall
    # be pre-processed before the execution. In the case when the
    # pTagToChange parameter is defined (the pParameter also SHALL BE defined!)
    # the pCommand parameter will be pre-processed:
    #   the pTagToChange value will be replaced by the pParameter value
    #   before the execution.
    def executeCmd(self, pCommand, pTagToChange=None, pParameter=None):
        self.command = pCommand
        self.parameter = pParameter
        self.subProcessRetVal = 0

        if (pTagToChange != None) and (pParameter != None):
            self.command = pCommand.replace(pTagToChange, pParameter)

        try:
            subprocess.check_call(self.command, shell=True,
                                stderr=subprocess.STDOUT,
                                universal_newlines=True)
        except subprocess.CalledProcessError as ex:
            sys.stderr.write("Error executing command: " + ex.cmd)
            sys.stderr.write("\n")
            sys.stderr.write("Exit code: " + str(ex.returncode) )
            sys.stderr.write("\n")
            self.subProcessRetVal = ex.returncode


