###############################################################################
#
# Copyright (C) 2013 Wind River Systems, Inc.
#
# This code is licensed under the GPLv2.
#
###############################################################################
import sys
import string


###############################################################################
# Class definition
#
# Representation/encapsulation of an analysis result set.
# This class has the following data structure:
#   1. list of titles
#   2. list of results
# These two lists are linked together, meaning that for one element in the
# titleList one element will be present in the resultList.
#
# A titleList element is a simple string, which acts as "key" identification
# for an element into the resultList.
#
# A resultList element is a list of tuples. So, each resultList element is
# another list of tuples. A tuple is composed by 3 elements (strings), and
# has the following meanings:
#   T0 - parameter name (the param which was compared)
#   T1 - the parameter current value (on the actually running system)
#   T2 - the parameter desired value (depends on the tuning against we compare)
###############################################################################
class OVP_OTT_ANALYSIS_RESULT:

    # Class initializer, allocates the two main lists.
    def __init__(self):
        self.titleList = []
        self.resultList = []


    # Adds a new (empty) result list into the resultList internal list, and
    # the associated name into the titleList.
    def createNewResultList(self, pResListName):
        self.titleList.append(pResListName)
        newResList = []
        self.resultList.append(newResList)


    # Adds a result (tuple) to the named resultList. In case the result list
    # doesn't exist, it will return False, otherwise True.
    def addResultToList(self, pResListName, pVal):
        if pResListName not in self.titleList:
            return False
        else:
            listPos = self.titleList.index(pResListName)
            self.resultList[listPos].append(pVal)
            return True


    # Returns the number of resultLists.
    def getNumberOfLists(self):
        return len(self.titleList)


    # Returns the total number of elements in ALL the result lists.
    def getTotalNumberOfElements(self):
        totVal = 0
        for list1 in self.resultList:
            totVal = totVal + len(list1)
        return totVal


    # Returns the resultList name, based on it's index in the list...
    def getResultGroupName(self, pIndex):
        return self.titleList[pIndex]


    # Returns one result list element based on its index or its name. 
    # A resultList element is a list of tuples; this will be returned.
    def getResultGroup(self, pIndex):
        if isinstance(pIndex, int):
            return self.resultList[pIndex]
        elif isinstance(pIndex, str):
            pidx = self.titleList.index(pIndex)
            return self.resultList[pidx]
        else:
            return None


    # Removes the named list from the result list and title list too.
    def removeResultList(self, pName):
        pidx = self.titleList.index(pName)
        self.titleList.pop(pidx)
        self.resultList.pop(pidx)


    # Internal method used to ease the development
    def showDebugInfo(self):
        print "TitleList: "
        print self.titleList
        print "Result List: "
        print self.resultList
