###############################################################################
#
# Copyright (C) 2013 Wind River Systems, Inc.
#
# This code is licensed under the GPLv2.
#
###############################################################################
import sys
import string

import ovp_ott_abs_reporter as ABSR


###############################################################################
# Class definition
#
# This class implements the abstract OVP_OTT_ABS_REPORTER class, and provides
# the functionality to report the results to the system console (STDOUT)
###############################################################################
class OVP_OTT_CONSOLE_REPORTER(ABSR.OVP_OTT_ABS_REPORTER):

    # The "main" and requested method, which shall be implemented by every
    # reporter object. It contains the whole "report logical organization"
    # calling all the sub-helper functions which do the reporting.
    def writeReport(self, pOvpOttAnalysisResult):
        self.result = pOvpOttAnalysisResult
        self.totalGroups = 0
        self.separatorLine=string.center('*',80,'*')
        self.__writeReportHeader()
        self.__writeReportSummary()
        for gr in range(0, self.totalGroups):
            self.__writeReportGroup(gr)
        self.__writeReportFooter()


    # This helper method centers the pString parameter on the text console
    # (STDOUT), and guard it with * characters
    def __writeCenteredString(self, pString):
        stri = " " + pString + " "
        stri = string.center(stri, 80, "*")
        print stri


    # This method implements the report header writing to the console.
    # It will show the report name/title and the report date.
    def __writeReportHeader(self):
        print self.separatorLine
        self.__writeCenteredString(self.getReportName())
        self.__writeCenteredString(self.getReportDate())
        print self.separatorLine
        print
        print


    # This method will write the report footer.
    def __writeReportFooter(self):
        print
        print self.separatorLine
        self.__writeCenteredString("Generated by OVP_OTT")
        print self.separatorLine


    # Writes the report summary part
    def __writeReportSummary(self):
        self.__writeCenteredString("Summary")
        self.totalGroups = self.result.getNumberOfLists()
        totNum = self.result.getTotalNumberOfElements()
        print "Total report groups: " + str(self.totalGroups)
        print "Overall total elements: " + str(totNum)
        print self.separatorLine


    # This helper method is responsible for writing out one chunk of
    # analysis data. It will try to create a tabular form, and
    # the data will be presented in concordance with a OVP_OTT_ANALYSIS_RESULT
    # tuple. Thus, the table will have 3 columns, in which will be shown as
    # follows:
    #   1. the analysed parameter name
    #   2. the parameter current value (no the currently running system)
    #   3. the parameter desired value (depending against which tuning values
    #      the comparison was made.
    def __writeReportGroup(self, pGroupNumber):
        print
        print
        grTitle = self.result.getResultGroupName(pGroupNumber)
        self.__writeCenteredString(grTitle)
        print self.separatorLine
        group = self.result.getResultGroup(pGroupNumber)
        print string.center("_", 80, "_")
        tabHead = "|" + string.center("Parameter", 26,' ') + "|" + \
            string.center("Current Value", 25, ' ') + "|" + \
            string.center("Desired Value", 25, ' ') + "|"
        print tabHead
        print string.center("-", 80, "-")
        for elem in group:
            lineToPrint = "|" + string.center(elem[0], 26, ' ')
            lineToPrint = lineToPrint + "|"
            lineToPrint = lineToPrint + string.center(elem[1], 25, " ")
            lineToPrint = lineToPrint + "|"
            lineToPrint = lineToPrint + string.center(elem[2], 25, " ")
            lineToPrint = lineToPrint + "|"
            print lineToPrint
        print string.center("_", 80, "_")
