###############################################################################
#
# Copyright (C) 2013 Wind River Systems, Inc.
#
# This code is licensed under the GPLv2.
#
###############################################################################
import sys
import datetime
from abc import ABCMeta, abstractmethod


###############################################################################
# Class definition
#
# This represent the base class for the reporting. It has all the generic
# methods that are common to all kind of reporters, such as report name
# date, etc.
# This is used to derive (implement) proper reporters, which actually will
# produce the desired output.
###############################################################################
class OVP_OTT_ABS_REPORTER:
    __metaclass__ = ABCMeta

    # This method sets the report name. It's up to the derived class if it
    # is used as filename, or report title too...
    def setReportName(self, pReportName):
        self.reportName = pReportName


    # Returns the current report name.
    def getReportName(self):
        return self.reportName


    # Sets the date of the report. To be mentioned that the
    # pDate parameter is a simple string here.
    def setReportDate(self, pDate):
        self.date = pDate


    # Return the report object date field/member value.
    def getReportDate(self):
        return self.date


    # Helper method, which reads the current system date, and set the internal
    # date value to this one.
    def setTodayReportDate(self):
        now = datetime.datetime.now()
        fmtTime = now.strftime("%Y-%m-%d %H:%M:%S")
        self.setReportDate(fmtTime)


    # Abstract method which shall be implemented by all derived classes.
    # Actually this will be the main point of the report creation, which
    # of course depends on the type of the report that will be created.
    # The pOvpOttAnalysisResult parameter is the OVP_OTT_ANALYSIS_RESULT type
    # which contain the results of a system analysis.
    @abstractmethod
    def writeReport(self, pOvpOttAnalysisResult):
        pass
